==> form-dinamico-react-render-0.5.10.tgz: package/es/widgets/mui/TextFieldWidget.js <==
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

import React from 'react';
import PropTypes from 'prop-types';

import TextField from '@material-ui/core/TextField';

function TextFieldWidget(props) {
    var value = props.value,
        readonly = props.readonly,
        disabled = props.disabled,
        autofocus = props.autofocus,
        onBlur = props.onBlur,
        onFocus = props.onFocus,
        options = props.options,
        schema = props.schema,
        formContext = props.formContext,
        registry = props.registry,
        required = props.required,
        inputProps = _objectWithoutProperties(props, ['value', 'readonly', 'disabled', 'autofocus', 'onBlur', 'onFocus', 'options', 'schema', 'formContext', 'registry', 'required']);

    var onChange = function onChange(_ref) {
        var value = _ref.target.value;

        return props.onChange(value ? value : options.emptyValue);
    };

    return React.createElement(TextField, _extends({
        margin: 'none',
        readOnly: readonly,
        disabled: schema.readonly,
        autoFocus: autofocus,
        required: schema.required,
        value: value || ''
    }, inputProps, {
        onChange: onChange,
        onBlur: onBlur && function (event) {
            return onBlur(inputProps.id, event.target.value);
        },
        onFocus: onFocus && function (event) {
            return onFocus(inputProps.id, event.target.value);
        },
        fullWidth: true
    }));
}

TextFieldWidget.defaultProps = {
    type: 'text',
    required: false,
    disabled: false,
    readonly: false,
    autofocus: false
};

TextFieldWidget.propTypes = process.env.NODE_ENV !== "production" ? {
    id: PropTypes.string.isRequired,
    placeholder: PropTypes.string,
    value: PropTypes.any,
    required: PropTypes.bool,
    disabled: PropTypes.bool,
    readonly: PropTypes.bool,
    autofocus: PropTypes.bool,
    onChange: PropTypes.func,
    onBlur: PropTypes.func,
    onFocus: PropTypes.func
} : {};

export default TextFieldWidget;

==> form-dinamico-react-render-0.8.5.tgz: package/es/widgets/mui/TextFieldWidget.js <==
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

import React from 'react';
import PropTypes from 'prop-types';

import TextField from '@material-ui/core/TextField';

function TextFieldWidget(props) {
    var value = props.value,
        readonly = props.readonly,
        disabled = props.disabled,
        autofocus = props.autofocus,
        onBlur = props.onBlur,
        onFocus = props.onFocus,
        options = props.options,
        schema = props.schema,
        metadata = props.schema.metadata,
        formContext = props.formContext,
        registry = props.registry,
        inputProps = _objectWithoutProperties(props, ['value', 'readonly', 'disabled', 'autofocus', 'onBlur', 'onFocus', 'options', 'schema', 'schema', 'formContext', 'registry']);

    var onChange = function onChange(_ref) {
        var value = _ref.target.value;

        return props.onChange(value ? value : options.emptyValue);
    };

    return React.createElement(TextField, _extends({}, inputProps, {
        margin: 'none',
        readOnly: metadata.readonly,
        disabled: metadata.readonly,
        autoFocus: autofocus,
        required: metadata.required,
        value: value || '',

        onChange: onChange,
        onBlur: onBlur && function (event) {
            return onBlur(inputProps.id, event.target.value);
        },
        onFocus: onFocus && function (event) {
            return onFocus(inputProps.id, event.target.value);
        },
        fullWidth: true
    }));
}

TextFieldWidget.defaultProps = {
    type: 'text',
    required: false,
    disabled: false,
    readonly: false,
    autofocus: false
};

TextFieldWidget.propTypes = process.env.NODE_ENV !== "production" ? {
    id: PropTypes.string.isRequired,
    placeholder: PropTypes.string,
    value: PropTypes.any,
    required: PropTypes.bool,
    disabled: PropTypes.bool,
    readonly: PropTypes.bool,
    autofocus: PropTypes.bool,
    onChange: PropTypes.func,
    onBlur: PropTypes.func,
    onFocus: PropTypes.func
} : {};

export default TextFieldWidget;
